@@ -13,7 +13,7 @@ use File::Spec;
 use Getopt::Long 2.33;
 use Scalar::Util 1.26 qw{ blessed looks_like_number };
 
-our $VERSION = '0.026_01';
+our $VERSION = '0.026_02';
 
 our @EXPORT_OK = qw{
     __arguments expand_tilde
@@ -208,15 +208,7 @@ sub instance {
 		and next;
 	    ( my $fn = $package ) =~ s{ :: }{/}smxg;
 	    eval {
-		# The following rigamarole is because some versions of
-		# Date::Manip, under some operating systems, change the
-		# working directory.
-		my $cwd = Cwd::cwd();
 		require "$fn.pm";	## no critic (RequireBarewordIncludes)
-		if ( $cwd ne Cwd::cwd() ) {
-		    chdir $cwd;
-#		    warn "Debug - $package does a chdir()";
-		}
 		1;
 	    } or next;
 	    return ( $loaded{$key} = $package );
